==> haskell-comonad-5.0.4-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.4
id: comonad-5.0.4-It8ddWRP4jRldNSP0vxVN
key: comonad-5.0.4-It8ddWRP4jRldNSP0vxVN
license: BSD-3-Clause
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads.
category: Control, Comonads
abi: 0f35087c8956a2594f3ac97c740fb7d9
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
import-dirs: /usr/lib/ghc-8.6.4/site-local/comonad-5.0.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/comonad-5.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/comonad-5.0.4
hs-libraries: HScomonad-5.0.4-It8ddWRP4jRldNSP0vxVN
depends:
    base-4.12.0.0 containers-0.6.0.1
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV
    distributive-0.6-9NCAlubkmNk4BRxn0siLZI
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-comonad-5.0.4-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.4
id: comonad-5.0.4-8UKAvbVXEvJ8FD0FgJJhEO
key: comonad-5.0.4-8UKAvbVXEvJ8FD0FgJJhEO
license: BSD-3-Clause
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads.
category: Control, Comonads
abi: 3dddef8559e36593958b02d6a4cf6ef6
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
import-dirs: /usr/lib/ghc-8.6.4/site-local/comonad-5.0.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/comonad-5.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/comonad-5.0.4
hs-libraries: HScomonad-5.0.4-8UKAvbVXEvJ8FD0FgJJhEO
depends:
    base-4.12.0.0 containers-0.6.0.1
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV
    distributive-0.6-L2Z1Ut3SFoa7TwkqYDUZRe
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
